package vishnu.datablock;
import java.io.*;

public class SparseMatrix implements Serializable
{
    private SparseNode [] nodes;
    private int n_cols;
    private int n_rows;
    
    public SparseMatrix(int rows, int cols)
    {
        n_rows = rows;
	n_cols = cols;
	
        nodes = new SparseNode[n_rows];
	
        for (int c = 0; c < n_rows; c++)
	    nodes[c] = null;
    }
    
    
    public void addDataItem(int row, int column, float value)
    {
	SparseNode node; 
	node = new SparseNode(value, column);
	nodes[row] = node.push(nodes[row]);
    }
    
    
    public SparseNode getRow(int row)
    {
	return nodes[row];
    }


    public int getRowCount()
    {
	    return n_rows;
    }


    public int getColumnCount()
    {
	    return n_cols;
    }
    

    public float[][] getExpanded()
    {
        float[][] full = new float[n_rows][n_cols];
	
	SparseNode n;
	
	for(int r = 0; r < n_rows; r++){
	    for (int c = 0; c < n_cols; c++)
		full[r][c]=0;
	    
	    n=nodes[r];
	    
	    while(n!= null){
		full[r][n.getColumn()]=n.getValue();
		n=n.getNext();
	    }
	}
	return full;
    }
    
    
    public void print()
    {
	for( int i = 0; i < nodes.length; i++ ){
	    SparseNode n = getRow(i);
	    while(n != null ){
		System.out.print(n.getColumn()+ " ");
		n = n.getNext();
	    }
	    System.out.println();
	}
    }
}

